@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::FLORA::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.06';
+  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.07';
 }
 # ABSTRACT: Build your distributions like FLORA does
 
@@ -231,18 +231,24 @@ distributions.
 It is roughly equivalent to:
 
   [@Filter]
-  bundle = @Classic
-  remove = PodVersion
-  remove = BumpVersion
+  bundle = @Basic
 
   [MetaConfig]
   [MetaJSON]
+  [PkgVersion]
+  [PodSyntaxTests]
+  [PodCoverageTests]
+  [SanityTests]
 
   [MetaResources]
   repository = git://github.com/rafl/${lowercase_dist}
   bugtracker = http://rt.cpan.org/Public/Dist/Display.html?Name=${dist}
   homepage   = http://search.cpan.org/dist/${dist}
 
+  [Authority]
+  authority   = cpan:FLORA
+  do_metadata = 1
+
   [PodWeaver]
   config_plugin = @FLORA
 
